# dqpy &middot; [![Build Status](https://travis-ci.org/danqing/dqpy.svg?branch=master)](https://travis-ci.org/danqing/dqpy) [![Coverage Status](https://coveralls.io/repos/github/danqing/dqpy/badge.svg?branch=master)](https://coveralls.io/github/danqing/dqpy?branch=master) [![PyPI version](https://badge.fury.io/py/dqpy.svg)](https://badge.fury.io/py/dqpy)

Danqing's shared Python library. Documentation: https://dqpy.danqing.io.

## Install

Install `dqpy` with `pip`:

```sh
pip install dqpy
```

## Develop

Set up the environment with:

```sh
virtualenv -p python3 env
make bootstrap
```

Tests can be run with:

```sh
make test
```

## License

MIT.
